@@ -7,7 +7,7 @@ use interface qw(Gtk2::Ex::DbLinker::AbDataManager);
 use Carp qw(carp croak confess cluck);
 use Data::Dumper;
 use Try::Tiny;
-use base qw(Gtk2::Ex::DbLinker::Recordset);
+use parent qw(Gtk2::Ex::DbLinker::Recordset);
 
 #my %fieldtype = (tinyint => "integer", "int" => "integer");
 
