@@ -9,7 +9,7 @@ use Data::Dumper;
 use SQL::Abstract::More;
 use Try::Tiny;
 
-use base qw(Gtk2::Ex::DbLinker::Recordset);
+use parent qw(Gtk2::Ex::DbLinker::Recordset);
 
 #my %fieldtype = (tinyint => "integer", "int" => "integer");
 
@@ -264,8 +264,9 @@ sub _get_rows_from_batch {
   # $local_sql .= " ( " . join( ",", $self->{keyset}[$counter] ) . " ),";
   #my @pk_vals = @{$all_pk_vals[$counter]};
   #my $value = $pk_val->[]
-  #$self->{log}->debug("pk :", $pk, " row : ", $counter++, " value: ", $pk_val);
-            push @vals_for_pk, $pk_val unless ( $seen{$pk_val}++ );
+  $self->{log}->debug("pk :", $pk, " value: ", $pk_val);
+ 
+   push @vals_for_pk, $pk_val unless ( $seen{$pk_val}++ );
 
             #push @where_new, %where;
 
